@@ -147,8 +147,8 @@ connection_cb(ConIcConnection *connection, ConIcConnectionEvent *event,
                 app->iap_connected = FALSE;
             app->iap_connecting_timer = 0;
             if((app->config->downloading_after_connecting) &&
-              (bearer && !strncmp(bearer,"WLAN", 4) && app->config->update_wlan) ||
-              (bearer && !strncmp(bearer,"DUN_GSM", 7) && app->config->update_gsm)){
+              ((bearer && !strncmp(bearer,"WLAN", 4) && app->config->update_wlan) ||
+              (bearer && !strncmp(bearer,"DUN_GSM", 7) && app->config->update_gsm))){
                 add_current_time_event();
             }
 
@@ -577,6 +577,15 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
         /* Skip Empty  station */
         while (1){
             if (station_code && (!strcmp(station_code," ") || !strcmp(station_code,_("Unknown"))) ){
+                if (station_code){
+                    g_free(station_code);
+                    station_code = NULL;
+                }
+                if (station_source){
+                    g_free(station_source);
+                    station_source = NULL;
+                }
+ 
                 valid = gtk_tree_model_iter_next(GTK_TREE_MODEL
                                          (app->user_stations_list), &iter);
                 if (valid) {
@@ -610,7 +619,13 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
             /* prepare detail url */
             if(get_source_detail_url(app->sources_list, station_source)){
                 *buffer = 0;
-                snprintf(buffer, sizeof(buffer) - 1,
+                /* TO DO move this code to sources libs */
+                if (!strcmp(station_source,"gismeteo.ru")){
+                    snprintf(buffer, sizeof(buffer) - 1,
+                            get_source_detail_url(app->sources_list, station_source),
+                            get_new_gismeteo_code(station_code, station_source));
+                }else
+                    snprintf(buffer, sizeof(buffer) - 1,
                             get_source_detail_url(app->sources_list, station_source),
                             station_code);
                 *hour_url = g_strdup(buffer);
@@ -648,7 +663,6 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
 void
 check_current_connection(void){
     gchar *tmp = NULL;
-    gchar *tmp2 = NULL;
     gchar *gconf_path = NULL;
     gchar *type_of_connection = NULL;
     GConfClient *gconf_client = NULL;
@@ -711,7 +725,6 @@ get_data_from_url(const gchar *data_url, const gchar *name){
         curl_easy_setopt(data_curl, CURLOPT_FOLLOWLOCATION, 1);
         curl_easy_setopt(data_curl, CURLOPT_TIMEOUT, 30);
         curl_easy_setopt(data_curl, CURLOPT_CONNECTTIMEOUT, 10);
-//        curl_easy_setopt(data_curl, CURLOPT_HEADER, headers);
 
         result = curl_easy_perform(data_curl);
 
@@ -722,7 +735,7 @@ get_data_from_url(const gchar *data_url, const gchar *name){
             data.stream = NULL;
         }
         if(data.filename){
-        //     g_free(data.filename);
+             /* g_free(data.filename); */
              data.filename = NULL;
         }
         if(result == CURLE_OK)
