@@ -43,7 +43,10 @@ struct request_data{
 sqlite3*
 open_database(const char *path, const char *filename){
     sqlite3     *db = NULL;
-    gchar       name[256];
+    gchar       name[4096];
+    gint        rc;
+    gchar       *errMsg = NULL;
+    gchar       *lang = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -51,15 +54,49 @@ open_database(const char *path, const char *filename){
         return NULL;
     *name = 0;
     snprintf(name, sizeof(name) - 1, "%s%s", path, filename);
+    if(access(name, R_OK)){  /* Not Access to db file */
+        return NULL;
+    }
+#ifdef OS2009
+    if(sqlite3_open_v2(name, &db, SQLITE_OPEN_READONLY, NULL)){
+#else
     if(sqlite3_open(name, &db)){
+#endif
         fprintf(stderr,"Error in connection to database %s\n",sqlite3_errmsg(db));
         return NULL;   /* error */
+    }else{
+          /* Choose russian_name field for gismeteo.ru */
+          if (!strcmp(filename,"gismeteo.ru.db")){
+              if(!(lang = getenv("LC_ALL")))
+                  if(!(lang = getenv("LC_MESSAGES")))
+                      lang = getenv("LANG");
+
+              if (lang && !strcmp(lang, "ru_RU"))
+                  rc = sqlite3_exec(db, "CREATE TEMP VIEW nstations AS SELECT russian_name as name, id, region_id, longititude, latitude, code  FROM stations",
+                        NULL, NULL, &errMsg);
+              else
+                  rc = sqlite3_exec(db, "CREATE TEMP VIEW nstations AS SELECT * FROM stations where russian_name != name",
+                        NULL, NULL, &errMsg);
+          }else{
+
+              rc = sqlite3_exec(db, "CREATE TEMP VIEW nstations AS SELECT * FROM stations",
+                        NULL, NULL, &errMsg);
+          }
+          if(rc != SQLITE_OK){
+              fprintf(stderr, "Problem %s\n", errMsg);
+              sqlite3_free(errMsg);
+          }
+
     }
     return db;
 }
 /*******************************************************************************/
 void
 close_database(sqlite3 *database){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
     if(database)
         sqlite3_close(database);
 }
@@ -75,7 +112,7 @@ create_countries_list(sqlite3 *database){
     if(!database)
         return NULL;    /* database doesn't open */
     list = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-    rc = sqlite3_exec(database, "SELECT name, id FROM countries ORDER BY name",
+    rc = sqlite3_exec(database, "SELECT name, id FROM countries where (select count(name) from nstations where nstations.region_id = (select distinct regions.id from regions where regions.country_id=countries.id )) > 0 ORDER BY name",
                         countries_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
 #ifndef RELEASE
@@ -141,16 +178,18 @@ create_stations_list(sqlite3 *database, int region_id){
     gint                rc;
     gchar               *errMsg = NULL,
                         sql[256];
+
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+
     if(!database || region_id == 0 || region_id == -1)
         return NULL;/* database doesn't open */
     list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_DOUBLE,
                                 G_TYPE_DOUBLE);
     *sql = 0;
     snprintf(sql, sizeof(sql) - 1,
-        "SELECT name, code, longititude, latitude FROM stations WHERE \
+        "SELECT name, code, longititude, latitude FROM nstations WHERE \
         region_id = %d ORDER BY name", region_id);
     rc = sqlite3_exec(database, sql, stations_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
@@ -179,11 +218,11 @@ get_all_information_callback(void *user_data, int argc, char **argv, char **azCo
     for(i = 0; i < argc; i++){
         if(!strcmp(azColName[i], "cname"))
             gtk_list_store_set(list, &iter, 0, argv[i], -1);
-        if(!strcmp(azColName[i], "name"))
+        if(!strcmp(azColName[i], "rname"))
             gtk_list_store_set(list, &iter, 1, argv[i], -1);
         if(!strcmp(azColName[i], "cid"))
             gtk_list_store_set(list, &iter, 2, atoi(argv[i]), -1);
-        if(!strcmp(azColName[i], "region_id"))
+        if(!strcmp(azColName[i], "rid"))
             gtk_list_store_set(list, &iter, 3, atoi(argv[i]), -1);
     }
 #ifdef DEBUGFUNCTIONCALL
@@ -208,10 +247,12 @@ get_all_information_about_station(gchar *source, gchar *station_code){
     if (!database)
         return NULL;
     list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
-    snprintf(sql, sizeof(sql) - 1, "Select countries.name as cname, regions.name, countries.id as cid, \
-                                    stations.region_id from stations,regions,countries \
-                                    where stations.code='%s' and stations.region_id=regions.id and \
-                                    regions.country_id=countries.id and countries.id=regions.country_id",
+    snprintf(sql, sizeof(sql) - 1, "Select countries.name as cname, regions.name as rname, \
+                                    countries.id as cid, nstations.region_id as rid \
+                                    from nstations,regions,countries \
+                                    where nstations.code='%s' and nstations.region_id=regions.id \
+                                    and regions.country_id=countries.id \
+                                    and countries.id=regions.country_id",
                                     station_code);
     rc = sqlite3_exec(database, sql, get_all_information_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
@@ -219,9 +260,14 @@ get_all_information_about_station(gchar *source, gchar *station_code){
       fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
         sqlite3_free(errMsg);
+        close_database(database);
         return NULL;
     }
     close_database(database);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
     return list;
 }
 /*******************************************************************************/
@@ -251,6 +297,11 @@ get_country_code(gchar *source, gchar *country_name){
       fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
         sqlite3_free(errMsg);
+        if (list){
+            gtk_list_store_clear(list);
+            g_object_unref(list);
+        }
+
         return -1;
     }
     close_database(database);
@@ -258,6 +309,12 @@ get_country_code(gchar *source, gchar *country_name){
                                       (list), &iter);
     if(valid)
       gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &rc, -1);
+
+    if (list){
+        gtk_list_store_clear(list);
+        g_object_unref(list);
+    }
+
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -297,6 +354,11 @@ get_state_code(gchar *source, gchar *region_name){
                                       (list), &iter);
     if(valid)
         gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &rc, -1);
+    if (list){
+        gtk_list_store_clear(list);
+        g_object_unref(list);
+    }
+        
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -323,7 +385,7 @@ get_station_code(gchar *source, gint region_id, gchar *station_name){
         return NULL;
     list = gtk_list_store_new(1, G_TYPE_STRING);
     /* Correct SQL */
-    snprintf(sql, sizeof(sql) - 1, "Select code from stations \
+    snprintf(sql, sizeof(sql) - 1, "Select code from nstations \
                                     where name='%s' and region_id='%i'", station_name, region_id);
     rc = sqlite3_exec(database, sql, get_station_code_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
@@ -331,12 +393,74 @@ get_station_code(gchar *source, gint region_id, gchar *station_name){
       fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
         sqlite3_free(errMsg);
+        close_database(database);
+
+        if (list){
+            gtk_list_store_clear(list);
+            g_object_unref(list);
+        }
         return NULL;
     }
     close_database(database);
     valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list), &iter);
     if(valid)
         gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &code, -1);
+    if (list){
+            gtk_list_store_clear(list);
+            g_object_unref(list);
+    }
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return code;
+}
+/*******************************************************************************/
+gchar*
+get_new_gismeteo_code(gchar *old_code, gchar *source){
+    sqlite3             *database = NULL;
+    gchar               buffer[2048],
+                        *errMsg = NULL,
+                        sql[1024];
+    gint                rc;
+    GtkListStore        *list = NULL;
+    GtkTreeIter         iter;
+    gboolean            valid;
+    gchar               *code;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    snprintf(buffer, sizeof(buffer) - 1, "%s.db",source);
+    database = open_database(DATABASEPATH, buffer);
+    if(!database)
+        return NULL;
+    list = gtk_list_store_new(1, G_TYPE_STRING);
+    /* Correct SQL */
+    snprintf(sql, sizeof(sql) - 1, "Select id_gismeteo_new from nstations \
+                                    where id_gismeteo_old='%s'", old_code);
+    rc = sqlite3_exec(database, sql, get_station_new_code_callback, (void*)list, &errMsg);
+    if(rc != SQLITE_OK){
+#ifndef RELEASE
+      fprintf(stderr, "\n>>>>%s\n", errMsg);
+#endif
+        sqlite3_free(errMsg);
+        close_database(database);
+
+        if (list){
+            gtk_list_store_clear(list);
+            g_object_unref(list);
+        }
+        return NULL;
+    }
+    close_database(database);
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list), &iter);
+    if(valid)
+        gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &code, -1);
+    if (list){
+            gtk_list_store_clear(list);
+            g_object_unref(list);
+    }
+
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -357,10 +481,10 @@ search_station_in_database(sqlite3 *database, char *code_name){
     list = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
               G_TYPE_STRING);
     snprintf(sql, sizeof(sql) - 1,
-        "SELECT stations.name, sources.code, regions.name AS region_name, \
-        countries.name AS country_name FROM stations JOIN sources,regions, \
-        countries ON stations.id = sources.station_id AND stations.region_id \
-        = regions.id AND regions.country_id = countries.id WHERE stations.name \
+        "SELECT nstations.name, sources.code, regions.name AS region_name, \
+        countries.name AS country_name FROM nstations JOIN sources,regions, \
+        countries ON nstations.id = sources.station_id AND nstations.region_id \
+        = regions.id AND regions.country_id = countries.id WHERE nstations.name \
         LIKE('%s%%') OR sources.code LIKE('%s%%')",
         code_name, code_name);
     rc = sqlite3_exec(database, sql, search_callback, (void*)list, &errMsg);
@@ -406,7 +530,6 @@ get_country_code_callback(void *user_data, int argc, char **argv, char **azColNa
     for(i = 0; i < argc; i++){
         if(!strcmp(azColName[i], "id"))
             gtk_list_store_set(list, &iter, 0, atoi(argv[i]), -1);
-        fprintf(stderr,"azColName[i] %s %i",azColName[i],atoi(argv[i]));
     }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -435,6 +558,26 @@ get_station_code_callback(void *user_data, int argc, char **argv, char **azColNa
 }
 /*******************************************************************************/
 int
+get_station_new_code_callback(void *user_data, int argc, char **argv, char **azColName){
+    int                 i;
+    GtkTreeIter         iter;
+    GtkListStore        *list = GTK_LIST_STORE(user_data);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+/* add new item for each first element */
+    gtk_list_store_append(list, &iter);
+    for(i = 0; i < argc; i++){
+        if(!strcmp(azColName[i], "id_gismeteo_new"))
+            gtk_list_store_set(list, &iter, 0, argv[i], -1);
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    return 0;
+}
+/*******************************************************************************/
+int
 get_state_code_callback(void *user_data, int argc, char **argv, char **azColName){
     int                 i;
     GtkTreeIter         iter;
@@ -447,7 +590,6 @@ get_state_code_callback(void *user_data, int argc, char **argv, char **azColName
     for(i = 0; i < argc; i++){
         if(!strcmp(azColName[i], "id"))
             gtk_list_store_set(list, &iter, 0, atoi(argv[i]), -1);
-        fprintf(stderr,"azColName[i] %s %i",azColName[i],atoi(argv[i]));
     }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
